EasyLocalizationHelper class

Constructors

EasyLocalizationHelper({List<String> languages = const ['en', 'de', 'fr', 'ja', 'es', 'pt', 'ko', 'zh', 'vi', 'ru'], String folderPath = 'assets/translations', dynamic jsonContent = const {'app_name' : 'New App'}, String defaultLocale = 'en'})

Properties

defaultLocale String
final
folderPath String
final
hashCode int
The hash code for this object.
no setterinherited
jsonContent → dynamic
final
languages List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareJsonKeys(String locale) → void
compareJsonKeysAll() → void
createLocaleFolder(String locale) → void
init() → void
initAssetFolders() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateJson({String? target}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited