FastlaneUtils class

Constructors

FastlaneUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAppFile() → void
checkDeployBat() → void
checkFastFile() → void
checkGemFile() → void
copyAppFile() → void
copyDeployBat() → void
copyFastFile() → void
copyGemFile() → void
init() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hasFastlane({String? projectRoot}) bool