PubspecYamlValidator class

Constructors

PubspecYamlValidator({Map<String, String> requiredDeps = const {'intl' : '^0.20.2', 'uuid' : '^4.5.2', 'package_info_plus' : '^9.0.0', 'equatable' : '^2.0.7', 'collection' : '^1.19.1', 'url_launcher' : '^6.3.2', 'shared_preferences' : '^2.5.3', 'json_annotation' : '^4.9.0', 'in_app_purchase' : '^3.2.3', 'fluttertoast' : '^9.0.0', 'device_info_plus' : '^12.2.0', 'logger' : '^2.6.1', 'firebase_core' : '^4.2.1', 'firebase_crashlytics' : '^5.0.5', 'firebase_auth' : '^6.1.2', 'google_mobile_ads' : '^6.0.0', 'share_plus' : '^12.0.1', 'retrofit' : '^4.9.1', 'dio' : '^5.9.0', 'dio_smart_retry' : '^7.0.1', 'bloc_concurrency' : '^0.3.0', 'path_provider' : '^2.1.5', 'crypto' : '^3.0.7', 'bloc' : '^9.0.1', 'flutter_bloc' : '^9.1.1', 'copy_with_extension' : '^10.0.1', 'in_app_purchase_android' : '^0.4.0+8', 'permission_handler' : '^12.0.1', 'image' : '^4.5.4', 'path' : '^1.9.1', 'stream_transform' : '^2.1.1', 'easy_localization' : '^3.0.8'}, Map<String, String> requiredDevDeps = const {'build_runner' : '^2.4.9', 'json_serializable' : '^6.11.3', 'yaml' : '^3.1.3'}})

Properties

hashCode int
The hash code for this object.
no setterinherited
requiredDeps Map<String, String>
final
requiredDevDeps Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited