SettingsGradleValidator class

Constructors

SettingsGradleValidator({Map<String, String> requiredPlugins = const {'dev.flutter.flutter-plugin-loader' : '1.0.0', 'com.android.application' : '8.12.2', 'org.jetbrains.kotlin.android' : '2.1.0'}})

Properties

hashCode int
The hash code for this object.
no setterinherited
requiredPlugins Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settingsPath String
final

Methods

compareVersions(String a, String b) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited