AppBuildGradleValidator class
Constructors
-
AppBuildGradleValidator({Map<
String, String> requiredAndroid = const {'compileSdk' : 'flutter.compileSdkVersion', 'ndkVersion' : 'flutter.ndkVersion'}, Map<String, String> requiredCompileOptions = const {'sourceCompatibility' : 'JavaVersion.VERSION_11', 'targetCompatibility' : 'JavaVersion.VERSION_11'}, Map<String, String> requiredKotlinOptions = const {'jvmTarget' : 'JavaVersion.VERSION_11.toString()'}, Map<String, String> requiredDefaultConfig = const {'minSdk' : 'flutter.minSdkVersion', 'targetSdk' : 'flutter.targetSdkVersion', 'versionCode' : 'flutter.versionCode', 'versionName' : 'flutter.versionName'}, Map<String, String> requiredFlutter = const {'source' : '"../.."'}})
Properties
- buildGradlePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requiredAndroid
→ Map<
String, String> -
final
-
requiredCompileOptions
→ Map<
String, String> -
final
-
requiredDefaultConfig
→ Map<
String, String> -
final
-
requiredFlutter
→ Map<
String, String> -
final
-
requiredKotlinOptions
→ Map<
String, String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited