GradleWrapperValidator class
Constructors
-
GradleWrapperValidator({Map<
String, String> required = const {'distributionBase' : 'GRADLE_USER_HOME', 'distributionPath' : 'wrapper/dists', 'zipStoreBase' : 'GRADLE_USER_HOME', 'zipStorePath' : 'wrapper/dists', 'distributionUrl' : 'https://services.gradle.org/distributions/gradle-8.13-all.zip'}})
Properties
- gradleWrapperPath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
required
→ Map<
String, String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compareVersions(
String a, String b) → int -
extractVersion(
String url) → String -
normalizeGradleValue(
String v) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited