ValidatorUtils class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkLineByLine(
{required String targetPath, required String templatePath}) → bool - Returns true if target file matches template exactly, false otherwise
-
ensureFileExists(
{required String templatePath, required String targetPath}) → void